/*
 *  The license and distribution terms for this file may be
 *  found in the file LICENSE in this distribution or at
 *  http://www.rtems.com/license/LICENSE.
 *
 *  $Id$
 */

/*
 * For now, this file is just a stub to work around
 * structural deficiencies of the powerpc port.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

